@@ -7,6 +7,7 @@ extern "C" {
 
 #include <string.h>
 #include "glbopts.h"
+#include "aa.h"
 
 /* private data structs (that you define) containing any necessary data to solve
  * linear system, etc. this defines the matrix A, only the linear system solver
@@ -57,7 +58,8 @@ struct SCS_SETTINGS {
   scs_int verbose;    /* boolean, write out progress: 1 */
   scs_int warm_start; /* boolean, warm start (put initial guess in ScsSolution
                          struct): 0 */
-  scs_int acceleration_lookback;
+  scs_int acceleration_lookback; /* memory for acceleration */
+  const char* write_data_filename; /* string, if set will dump data */
 };
 
 /* NB: rows of data matrix A must be specified in this exact order */
@@ -122,18 +124,18 @@ const char *SCS(version)(void);
 
 /* workspace for SCS */
 struct SCS_WORK {
-  scs_float *u, *v, *u_t, *u_prev,
-      *v_prev; /* x_prev = x from previous iteration */
+  /* x_prev = x from previous iteration */
+  scs_float *u, *v, *u_t, *u_prev, *v_prev;
   scs_float *h, *g, *pr, *dr;
   scs_float g_th, sc_b, sc_c, nm_b, nm_c;
   scs_float *b, *c;       /* (possibly normalized) b and c vectors */
   scs_int m, n;           /* A has m rows, n cols */
   ScsMatrix *A;           /* (possibly normalized) A matrix */
   ScsLinSysWork *p;       /* struct populated by linear system solver */
-  ScsAccelWork *accel;    /* Struct for acceleration workspace */
   ScsSettings *stgs;      /* contains solver settings specified by user */
   ScsScaling *scal;       /* contains the re-scaling data */
   ScsConeWork *cone_work; /* workspace for the cone projection step */
+  AaWork *accel;          /* Struct for acceleration workspace */
 };
 
 /* to hold residual information (unnormalized) */
